[−][src]Struct sc_block_builder::BlockBuilder
Utility for building new (valid) blocks from a stream of extrinsics.
Methods
impl<'a, Block, A, B> BlockBuilder<'a, Block, A, B> where
Block: BlockT,
A: ProvideRuntimeApi<Block> + 'a,
A::Api: BlockBuilderApi<Block, Error = Error> + ApiExt<Block, StateBackend = StateBackendFor<B, Block>>,
B: Backend<Block>, [src]
Block: BlockT,
A: ProvideRuntimeApi<Block> + 'a,
A::Api: BlockBuilderApi<Block, Error = Error> + ApiExt<Block, StateBackend = StateBackendFor<B, Block>>,
B: Backend<Block>,
pub fn new(
api: &'a A,
parent_hash: Block::Hash,
parent_number: NumberFor<Block>,
record_proof: RecordProof,
inherent_digests: DigestFor<Block>,
backend: &'a B
) -> Result<Self, ApiErrorFor<A, Block>>[src]
api: &'a A,
parent_hash: Block::Hash,
parent_number: NumberFor<Block>,
record_proof: RecordProof,
inherent_digests: DigestFor<Block>,
backend: &'a B
) -> Result<Self, ApiErrorFor<A, Block>>
Create a new instance of builder based on the given parent_hash and parent_number.
While proof recording is enabled, all accessed trie nodes are saved. These recorded trie nodes can be used by a third party to prove the output of this block builder without having access to the full storage.
pub fn push(
&mut self,
xt: <Block as BlockT>::Extrinsic
) -> Result<(), ApiErrorFor<A, Block>>[src]
&mut self,
xt: <Block as BlockT>::Extrinsic
) -> Result<(), ApiErrorFor<A, Block>>
Push onto the block's list of extrinsics.
This will ensure the extrinsic can be validly executed (by executing it).
pub fn push_trusted(
&mut self,
xt: <Block as BlockT>::Extrinsic
) -> Result<(), ApiErrorFor<A, Block>>[src]
&mut self,
xt: <Block as BlockT>::Extrinsic
) -> Result<(), ApiErrorFor<A, Block>>
Push onto the block's list of extrinsics.
This will treat incoming extrinsic xt as trusted and skip signature check (for signed transactions).
pub fn build(
self
) -> Result<BuiltBlock<Block, StateBackendFor<B, Block>>, ApiErrorFor<A, Block>>[src]
self
) -> Result<BuiltBlock<Block, StateBackendFor<B, Block>>, ApiErrorFor<A, Block>>
Consume the builder to build a valid Block containing all pushed extrinsics.
Returns the build Block, the changes to the storage and an optional StorageProof
supplied by self.api, combined as BuiltBlock.
The storage proof will be Some(_) when proof recording was enabled.